{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix

      ./hardware-configuration.nix

      ./services/nginx.nix
      ./services/metrics
      ./services/cloudflared.nix
    ];

  networking = {
    hostName = "chapel";
    defaultGateway = "192.168.10.1";
    interfaces.eth0.ipv4 = {
      addresses = [
        { address = "192.168.10.100"; prefixLength = 24; }
      ];
    };
  };

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    ((vim_configurable.override {  }).customize{
       name = "vim";
       vimrcConfig.packages.myplugins = with pkgs.vimPlugins; {
       start = [ vim-nix vim-lastplace ];
       opt = [];
     };
     vimrcConfig.customRC = ''
     " your custom vimrc
     set number
     set relativenumber
     set nu rnu
     set signcolumn=number

     set hlsearch
     set smartcase
     set incsearch

     set autoindent
     set expandtab
     set shiftwidth=2
     set tabstop=2
     set smartindent
     set smarttab

     set ruler

     set undolevels=1000

     set nocompatible
     set backspace=indent,eol,start
     " Turn on syntax highlighting by default
     syntax on
     " ...
     '';
    }
  )
  ];

  networking.firewall.allowedTCPPorts = [ 80 3100 ];

  # system.copySystemConfiguration = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}

